@@ -1,4 +1,4 @@
-# Copyright (c) 2008,2015,2016 MetPy Developers.
+# Copyright (c) 2008,2015,2016,2017,2018 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 """Contains a collection of basic calculations.
@@ -17,7 +17,7 @@ import warnings
 import numpy as np
 from scipy.ndimage import gaussian_filter
 
-from ..constants import G, g, me, omega, Rd, Re
+from .. import constants as mpconsts
 from ..deprecation import deprecated
 from ..package_tools import Exporter
 from ..units import atleast_1d, check_units, masked_array, units
@@ -103,7 +103,7 @@ def wind_components(speed, wdir):
         The wind speed (magnitude)
     wdir : array_like
         The wind direction, specified as the direction from which the wind is
-        blowing, with 360 degrees being North.
+        blowing (0-2 pi radians or 0-360 degrees), with 360 degrees being North.
 
     Returns
     -------
@@ -139,9 +139,9 @@ def get_wind_speed(u, v):
     return wind_speed(u, v)
 
 
-get_wind_speed.__doc__ = (wind_speed.__doc__ +
-                          '\n    .. deprecated:: 0.9.0\n        Function has been renamed to '
-                          '`wind_speed` and will be removed from MetPy in 0.12.0.')
+get_wind_speed.__doc__ = (wind_speed.__doc__
+                          + '\n    .. deprecated:: 0.9.0\n        Function has been renamed to'
+                            ' `wind_speed` and will be removed from MetPy in 0.12.0.')
 
 
 @exporter.export
@@ -153,9 +153,9 @@ def get_wind_dir(u, v):
     return wind_direction(u, v)
 
 
-get_wind_dir.__doc__ = (wind_direction.__doc__ +
-                        '\n    .. deprecated:: 0.9.0\n        Function has been renamed to '
-                        '`wind_direction` and will be removed from MetPy in 0.12.0.')
+get_wind_dir.__doc__ = (wind_direction.__doc__
+                        + '\n    .. deprecated:: 0.9.0\n        Function has been renamed to '
+                          '`wind_direction` and will be removed from MetPy in 0.12.0.')
 
 
 @exporter.export
@@ -167,10 +167,10 @@ def get_wind_components(u, v):
     return wind_components(u, v)
 
 
-get_wind_components.__doc__ = (wind_components.__doc__ +
-                               '\n    .. deprecated:: 0.9.0\n        Function has been '
-                               'renamed to `wind_components` and will be removed from MetPy '
-                               'in 0.12.0.')
+get_wind_components.__doc__ = (wind_components.__doc__
+                               + '\n    .. deprecated:: 0.9.0\n        Function has been '
+                                 'renamed to `wind_components` and will be removed from MetPy '
+                                 'in 0.12.0.')
 
 
 @exporter.export
@@ -223,8 +223,8 @@ def windchill(temperature, speed, face_level_winds=False, mask_undefined=True):
 
     temp_limit, speed_limit = 10. * units.degC, 3 * units.mph
     speed_factor = speed.to('km/hr').magnitude ** 0.16
-    wcti = units.Quantity((0.6215 + 0.3965 * speed_factor) * temperature.to('degC').magnitude -
-                          11.37 * speed_factor + 13.12, units.degC).to(temperature.units)
+    wcti = units.Quantity((0.6215 + 0.3965 * speed_factor) * temperature.to('degC').magnitude
+                          - 11.37 * speed_factor + 13.12, units.degC).to(temperature.units)
 
     # See if we need to mask any undefined values
     if mask_undefined:
@@ -275,11 +275,15 @@ def heat_index(temperature, rh, mask_undefined=True):
     delta2 = delta * delta
 
     # Calculate the Heat Index -- constants converted for RH in [0, 1]
-    hi = (-42.379 * units.degF + 2.04901523 * delta +
-          1014.333127 * units.delta_degF * rh - 22.475541 * delta * rh -
-          6.83783e-3 / units.delta_degF * delta2 - 5.481717e2 * units.delta_degF * rh2 +
-          1.22874e-1 / units.delta_degF * delta2 * rh + 8.5282 * delta * rh2 -
-          1.99e-2 / units.delta_degF * delta2 * rh2)
+    hi = (-42.379 * units.degF
+          + 2.04901523 * delta
+          + 1014.333127 * units.delta_degF * rh
+          - 22.475541 * delta * rh
+          - 6.83783e-3 / units.delta_degF * delta2
+          - 5.481717e2 * units.delta_degF * rh2
+          + 1.22874e-1 / units.delta_degF * delta2 * rh
+          + 8.5282 * delta * rh2
+          - 1.99e-2 / units.delta_degF * delta2 * rh2)
 
     # See if we need to mask any undefined values
     if mask_undefined:
@@ -379,7 +383,8 @@ def pressure_to_height_std(pressure):
     t0 = 288. * units.kelvin
     gamma = 6.5 * units('K/km')
     p0 = 1013.25 * units.mbar
-    return (t0 / gamma) * (1 - (pressure / p0).to('dimensionless')**(Rd * gamma / g))
+    return (t0 / gamma) * (1 - (pressure / p0).to('dimensionless')**(
+        mpconsts.Rd * gamma / mpconsts.g))
 
 
 @exporter.export
@@ -416,7 +421,7 @@ def height_to_geopotential(height):
 
     """
     # Calculate geopotential
-    geopot = G * me * ((1 / Re) - (1 / (Re + height)))
+    geopot = mpconsts.G * mpconsts.me * ((1 / mpconsts.Re) - (1 / (mpconsts.Re + height)))
 
     return geopot
 
@@ -458,7 +463,7 @@ def geopotential_to_height(geopot):
 
     """
     # Calculate geopotential
-    height = (((1 / Re) - (geopot / (G * me))) ** -1) - Re
+    height = (((1 / mpconsts.Re) - (geopot / (mpconsts.G * mpconsts.me))) ** -1) - mpconsts.Re
 
     return height
 
@@ -489,7 +494,7 @@ def height_to_pressure_std(height):
     t0 = 288. * units.kelvin
     gamma = 6.5 * units('K/km')
     p0 = 1013.25 * units.mbar
-    return p0 * (1 - (gamma / t0) * height) ** (g / (Rd * gamma))
+    return p0 * (1 - (gamma / t0) * height) ** (mpconsts.g / (mpconsts.Rd * gamma))
 
 
 @exporter.export
@@ -511,7 +516,7 @@ def coriolis_parameter(latitude):
 
     """
     latitude = _check_radians(latitude, max_radians=np.pi / 2)
-    return (2. * omega * np.sin(latitude)).to('1/s')
+    return (2. * mpconsts.omega * np.sin(latitude)).to('1/s')
 
 
 @exporter.export
@@ -710,6 +715,64 @@ def smooth_gaussian(scalar_grid, n):
     return res
 
 
+@exporter.export
+@preprocess_xarray
+def smooth_n_point(scalar_grid, n=5, passes=1):
+    """Filter with normal distribution of weights.
+
+    Parameters
+    ----------
+    scalar_grid : array-like or `pint.Quantity`
+        Some 2D scalar grid to be smoothed.
+
+    n: int
+        The number of points to use in smoothing, only valid inputs
+        are 5 and 9. Defaults to 5.
+
+    passes : int
+        The number of times to apply the filter to the grid. Defaults
+        to 1.
+
+    Returns
+    -------
+    array-like or `pint.Quantity`
+        The filtered 2D scalar grid.
+
+    Notes
+    -----
+    This function is a close replication of the GEMPAK function SM5S
+    and SM9S depending on the choice of the number of points to use
+    for smoothing. This function can be applied multiple times to
+    create a more smoothed field and will only smooth the interior
+    points, leaving the end points with their original values. If a
+    masked value or NaN values exists in the array, it will propagate
+    to any point that uses that particular grid point in the smoothing
+    calculation. Applying the smoothing function multiple times will
+    propogate NaNs further throughout the domain.
+
+    """
+    if n == 9:
+        p = 0.25
+        q = 0.125
+        r = 0.0625
+    elif n == 5:
+        p = 0.5
+        q = 0.125
+        r = 0.0
+    else:
+        raise ValueError('The number of points to use in the smoothing '
+                         'calculation must be either 5 or 9.')
+
+    smooth_grid = scalar_grid[:].copy()
+    for _i in range(passes):
+        smooth_grid[1:-1, 1:-1] = (p * smooth_grid[1:-1, 1:-1]
+                                   + q * (smooth_grid[2:, 1:-1] + smooth_grid[1:-1, 2:]
+                                          + smooth_grid[:-2, 1:-1] + smooth_grid[1:-1, :-2])
+                                   + r * (smooth_grid[2:, 2:] + smooth_grid[2:, :-2] +
+                                          + smooth_grid[:-2, 2:] + smooth_grid[:-2, :-2]))
+    return smooth_grid
+
+
 def _check_radians(value, max_radians=2 * np.pi):
     """Input validation of values that could be in degrees instead of radians.
 
