@@ -252,8 +252,6 @@ if not hasattr(Axes, 'scattertext'):
             self.y = y
             self.text = text
             self.offset = offset
-            if not hasattr(self, '_usetex'):  # Only needed for matplotlib 1.4 compatibility
-                self._usetex = None
 
         def __str__(self):
             """Make a string representation of `TextCollection`."""
@@ -378,29 +376,3 @@ if not hasattr(Axes, 'scattertext'):
 
     # Monkey-patch scattertext onto Axes
     Axes.scattertext = scattertext
-
-
-# See if we need to add in the Tableau colors which were added in Matplotlib 2.0
-import matplotlib.colors  # noqa: E402, I202
-if not hasattr(matplotlib.colors, 'TABLEAU_COLORS'):
-    from collections import OrderedDict
-
-    # These colors are from Tableau
-    TABLEAU_COLORS = (
-        ('blue', '#1f77b4'),
-        ('orange', '#ff7f0e'),
-        ('green', '#2ca02c'),
-        ('red', '#d62728'),
-        ('purple', '#9467bd'),
-        ('brown', '#8c564b'),
-        ('pink', '#e377c2'),
-        ('gray', '#7f7f7f'),
-        ('olive', '#bcbd22'),
-        ('cyan', '#17becf'),
-    )
-
-    # Normalize name to "tab:<name>" to avoid name collisions.
-    matplotlib.colors.TABLEAU_COLORS = OrderedDict(
-        ('tab:' + name, value) for name, value in TABLEAU_COLORS)
-
-    matplotlib.colors.cnames.update(matplotlib.colors.TABLEAU_COLORS)
