@@ -10,7 +10,6 @@ import re
 import warnings
 
 import xarray as xr
-from xarray.core.accessors import DatetimeAccessor
 from xarray.core.indexing import expanded_indexer
 from xarray.core.utils import either_dict_or_kwargs, is_dict_like
 
@@ -76,7 +75,7 @@ class MetPyAccessor(object):
                     return coord_var
             raise AttributeError(axis + ' attribute is not available.')
         else:
-            raise AttributeError('\'' + axis + '\' is not an interpretable axis.')
+            raise AttributeError("'" + axis + "' is not an interpretable axis.")
 
     def coordinates(self, *args):
         """Return the coordinate variables corresponding to the given axes types."""
@@ -452,17 +451,21 @@ def check_matching_coordinates(func):
     return wrapper
 
 
-# If DatetimeAccessor does not have a strftime, monkey patch one in
-if not hasattr(DatetimeAccessor, 'strftime'):
-    def strftime(self, date_format):
-        """Format time as a string."""
-        import pandas as pd
-        values = self._obj.data
-        values_as_series = pd.Series(values.ravel())
-        strs = values_as_series.dt.strftime(date_format)
-        return strs.values.reshape(values.shape)
+# If DatetimeAccessor does not have a strftime (xarray <0.12.2), monkey patch one in
+try:
+    from xarray.core.accessors import DatetimeAccessor
+    if not hasattr(DatetimeAccessor, 'strftime'):
+        def strftime(self, date_format):
+            """Format time as a string."""
+            import pandas as pd
+            values = self._obj.data
+            values_as_series = pd.Series(values.ravel())
+            strs = values_as_series.dt.strftime(date_format)
+            return strs.values.reshape(values.shape)
 
-    DatetimeAccessor.strftime = strftime
+        DatetimeAccessor.strftime = strftime
+except ImportError:
+    pass
 
 
 def _reassign_quantity_indexer(data, indexers):
